import setuptools

setuptools.setup(
        name='endaq',
        version='0.0.0a1',
        author='Mide Technology',
        author_email='help@mide.com',
        packages=[],
        package_dir={'endaq': './endaq'},
        install_requires=[],
)
